/*   Cataract - Static web photo gallery generator
 *   Copyright (C) 2008 Tomas Bzatek <tbzatek@users.sourceforge.net>
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef __CGG__GENERATORS_H__
#define __CGG__GENERATORS_H__

#include <glib.h>

#include "setup.h"
#include "items.h"

G_BEGIN_DECLS


/*
 *   generate_image: generate needed image sizes
 * 
 *      returns whether item needs to be updated  
 */
gboolean generate_image (TGallerySetup *setup,
                         TAlbum *items,
                         TIndexItem *item,
                         unsigned int item_index,
                         TPathInfo *path_info,
                         gboolean update_when_necessary);

/*
 *   write_html_album: process album and index template files
 *
 *      template_src  = template file of the album/index
 *      dst           = save generated file as
 *      items         = array of items in the album/index
 *
 */
gboolean write_html_album (TGallerySetup *setup,
                           TPathInfo *path_info,
                           const gchar *template_src,
                           const gchar *dst,
                           TAlbum *items);

/*
 *   write_html_image: process single image template file
 *
 *      template_src  = template file of the album/index
 *      dst           = save generated file as
 *      item          = data for the current item
 *      parent_items  = array of items in the album, to determine our position and make links to previous/next image
 *
 */
gboolean write_html_image (TGallerySetup *setup,
                           TPathInfo *path_info,
                           const gchar *template_src,
                           const gchar *dst,
                           TIndexItem *item,
                           TAlbum *parent_items);


G_END_DECLS

#endif /* __CGG__GENERATORS_H__ */
